@@ -186,10 +186,10 @@ class Quip:
             else:
                 self.update_icon()
         elif action in FIELD_ACTION:
-            if self.args.update:
-                self.update_fields(self.args.code)
-            elif self.args.dump:
+            if self.args.dump:
                 self.dump_fields(write=True)
+            else:
+                self.update_fields(self.args.code)
         elif action in UPDATE_ACTION:
             if self.args.rename_scripts:
                 self.update_rename_scripts()
@@ -1008,7 +1008,7 @@ class Quip:
             sys.exit(1)
 
     def update_all_sysid_values(self, template_content):
-        regex = re.compile(r"""\"sysId\"\s*:\s*\"([0-9a-f]{32})\"""")
+        regex = re.compile(r"""\"sysId\"\s*:\s*\"([^\"]+)\"""")
         matches = regex.finditer(template_content)
         olds = set()
         for match in matches:
@@ -1016,21 +1016,33 @@ class Quip:
             if old in olds:
                 continue
 
-            new = str(uuid.uuid4()).replace("-","")
+            new = self.get_new_uuid()
             logging.info(f"Updating SysID: {old} => {new}")
             template_content = template_content.replace(old, new)
             olds.add(old)
         
+        _json = json.loads(template_content)
+        if "sysId" in _json:
+            old = _json["sysId"]
+            if not regex.match(old):
+                new = self.get_new_uuid()
+                logging.info(f"Updating SysID: {old} => {new}")
+                _json["sysId"] = new
+                template_content = self.format_json(_json)
+        
         return template_content
 
     def update_new_uuid_values(self, template_content):
         old = '"new_uuid"'
         for i in range(template_content.count(old)):
-            new = "\"{}\"".format(str(uuid.uuid4()).replace("-",""))
+            new = "\"{}\"".format(self.get_new_uuid())
             logging.info(f"Updating SysID: {old} => {new}")
             template_content = template_content.replace(old, new, 1)
         
         return template_content
+    
+    def get_new_uuid(self):
+        return str(uuid.uuid4()).replace("-","")
 
 class QuipGlobalConfig:
     def __init__(self, config_file=None) -> None:
